@@ -1958,7 +1958,7 @@ void handle_guid_disconnect()
     }
     libvchan_close(g->vchan);
     wait_for_possible_dispvm_resume();
-    g->vchan = libvchan_server_init(0, 6000, 4096, 4096);
+    g->vchan = libvchan_server_init(g->domid, 6000, 4096, 4096);
     /* wait for gui daemon */
     while (libvchan_is_open(g->vchan) == VCHAN_WAITING)
         libvchan_wait(g->vchan);
