@@ -17,9 +17,7 @@
   General Public License for more details.
 
   You should have received a copy of the GNU Lesser General Public
-  License along with PulseAudio; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
-  USA.
+  License along with PulseAudio; if not, see <http://www.gnu.org/licenses/>.
 ***/
 
 #include <sys/types.h>
@@ -58,7 +56,7 @@ typedef struct pa_memblockq pa_memblockq;
                 if no data is in the queue and will never fail. Pass
                 (size_t) -1 for the default.
 
-   - minreq:    pa_memblockq_missing() will only return values greater
+   - minreq:    pa_memblockq_pop_missing() will only return values greater
                 than this value. Pass 0 for the default.
 
    - maxrewind: how many bytes of history to keep in the queue
@@ -114,9 +112,6 @@ bool pa_memblockq_is_readable(pa_memblockq *bq);
 /* Return the length of the queue in bytes */
 size_t pa_memblockq_get_length(pa_memblockq *bq);
 
-/* Return how many bytes are missing in queue to the specified fill amount */
-size_t pa_memblockq_missing(pa_memblockq *bq);
-
 /* Return the number of bytes that are missing since the last call to
  * this function, reset the internal counter to 0. */
 size_t pa_memblockq_pop_missing(pa_memblockq *bq);
